## SecretPlots

This library is heavily under development. Hence most of the APIs and
 functions will change until stable version is genertaed. 
 
 Please check after
  few days. Current Timeline is as follows,


1. Aug 2019 - Oct 2019 : Planning
2. Nov 2019 - Dec 2019 : Beta release
3. Mid 2020 : Stable release

You are welcome to try out early features and help us in developing this
 further. Checkout our GitHub page for the ongoing development. 
 
 
 [https://github.com/secretBiology/SecretPlots/](https://github.com/secretBiology/SecretPlots/)
